@@ -1,3 +1,5 @@
+
+
 #' Check and Install Required Packages
 #'
 #' This function checks if the required Bioconductor and CRAN packages are installed.
@@ -8,7 +10,6 @@
 #' \code{pheatmap}, \code{circlize}, \code{e1071}, and \code{colorRamps}.
 #'
 #' @return NULL This function does not return a value. It installs the packages as needed.
-#' @importFrom BiocManager install
 #' @importFrom utils install.packages
 #' @export
 check_dependency <- function(){
@@ -17,19 +18,21 @@ check_dependency <- function(){
     utils::install.packages("BiocManager")
   }
 
-  packages <- c("clusterProfiler",
+  packages <- c("Biobase",
+                "ComplexHeatmap",
+                "clusterProfiler",
                 "SummarizedExperiment",
                 "ComplexHeatmap",
-                "SingleCellExperiment",
                 "TCseq","monocle","Biobase")
 
-  # check needed packages
+  # check needed packages on BiocManager
   for (pkg in packages) {
     if (!requireNamespace(pkg, quietly = TRUE)) {
       BiocManager::install(pkg)
     }
   }
 
+  # check needed packages on CRAN
   crans <- c("Seurat","WGCNA","igraph","pheatmap","circlize","e1071","colorRamps")
 
   # check needed packages
@@ -38,4 +41,6 @@ check_dependency <- function(){
       utils::install.packages(pkg)
     }
   }
+
+
 }
